@@ -1,5 +1,6 @@
 import re
 import numpy as np
+import pandas as pd
 from numba import njit
 from itertools import chain
 from joblib import Parallel, delayed
@@ -8,6 +9,8 @@ from typing import Literal
 class LabelMatrix:
     def __init__(self):
         self.labels_ = None
+        self.control_label = None 
+        self.sep_pattern = None
     
     def fit_transform(self, labels, control_label=None, sep_pattern=r'[,;_\s]', speedup: Literal['none','vectorize','parallel']='none'):
         if speedup=='none':
@@ -24,8 +27,31 @@ class LabelMatrix:
             mat = np.delete(mat, idx, axis=1)
             self.labels_ = np.delete(self.labels_, idx)
             
+        self.control_label = control_label
+        self.sep_pattern=sep_pattern
+        
         return mat
-            
+    
+    def transform(self, labels, speedup: Literal['none','vectorize','parallel']='none'):
+        sep_pattern = self.sep_pattern
+        if speedup=='none':
+            mat, labels_ = label_to_matrix(labels=labels, sep_pattern=sep_pattern)
+        elif speedup=='vectorize':
+            mat, labels_ = vectorized_label_to_matrix(labels=labels, sep_pattern=sep_pattern)
+        elif speedup=='parallel':
+            mat, labels_ = parallel_label_to_matrix(labels=labels, sep_pattern=sep_pattern)
+          
+        mat_df = pd.DataFrame(mat, columns=labels_)
+        
+        labels_valid = [x for x in labels_ if x in self.labels_]  
+        mat_df = mat_df[labels_valid]
+        
+        mat_valid = np.zeros([mat.shape[0], len(self.labels_)])
+        mat_valid_df = pd.DataFrame(mat_valid, columns=self.labels_)
+        mat_valid_df[labels_valid] = mat_df 
+        
+        return mat_valid_df.values
+        
     def inverse_transform(self, matrix):
         return matrix_to_labels(matrix=matrix, unique_labels=self.labels_)
 
