@@ -7,7 +7,7 @@ from .utils import find_partitions_greedy
 
 from .queue import PriorityQueue
 
-from .custom_mlp import MLP, Exp, ZeroBiasMLP
+from .custom_mlp import MLP, Exp, ZeroBiasMLP, HDMLP
 
 # Importing modules
 #from . import utils
