@@ -237,12 +237,19 @@ class ZeroBiasMLP(nn.Module):
         
     # pass through our sequential for the output!
     def forward(self, x):
+        print(f'type: {type(x)}; shape: {x.shape}')
         y = self.mlp(x)
         mask = torch.zeros_like(y)
         if len(y.shape)==2:
-            mask[x[1][:,0]>0,:] = 1
+            if len(x)>2:
+                mask[x[1][:,0]>0,:] = 1
+            else:
+                mask[x[:,0]>0,:] = 1
         elif len(y.shape)==3:
-            mask[:,x[1][:,0]>0,:] = 1
+            if len(x)>1:
+                mask[:,x[1][:,0]>0,:] = 1
+            else:
+                mask[:,x[:,0]>0,:] = 1
         return y*mask
         
 
